import os
import sys
import glob
import shutil
import string
import getopt

from distutils.core import setup, gen_usage
from distutils.sysconfig import PREFIX, get_python_lib
from distutils.dist import Distribution
from distutils.errors import DistutilsArgError

# determine the prefix
prefix = PREFIX # default
klass = Distribution # we know, because we're not specifying it below
dist = klass()
dist.parse_config_files()
dist.script_name = sys.argv[0]
try: 
	ok = dist.parse_command_line()
except DistutilsArgError, msg: 
	pass # that'll get handled later on
# if defined, the prefix will be in one of the command_options
for command, options in dist.command_options.items(): 
	try: 
		prefix = options['prefix'][1]
	except KeyError: # no prefix option set
		pass

dfile_dir = os.path.join(prefix, 'share', 'pyds')
dfile_list = glob.glob('*.msgs')
dfile_list.extend(glob.glob('*.tmpl'))
dfile_list.extend(glob.glob('*.css'))
dfile_list.extend(glob.glob('*.gif'))
dfile_list.extend(glob.glob('*.png'))
dfile_list.extend(glob.glob('*.jpg'))
dfile_list.append('LICENSE')
dfile_list.append('README')
dfile_list.append('OVERVIEW')
dfile_list.append('INSTALL-FROM-SOURCE')
dfile_list.append('ChangeLog')

tool_dir = os.path.join(prefix, 'share', 'pyds', 'tools')
tool_list = glob.glob('tools/*.py')

font_dir = os.path.join(prefix, 'share', 'pyds', 'fonts')
font_list = glob.glob('fonts/*.pil')
font_list.extend(glob.glob('fonts/*.pbm'))

ldescription="""The python desktop server is a RSS aggregator, weblog editing
software and application server. It can be extended with plugins, with macros,
with templates and with external tools that use XML-RPC or SOAP to access
functionality. It has a configureable and themeable web interface. It adds
more functionality for content management (like a desktop wiki) and can be
used to manage rather complex sites that are hosted at a community server or
are published via FTP. Alternatively it can be used as a central hosted
CMS, too.
"""

setup(
	version = "0.6.5",
	description = "Python Desktop Server",
	author = "Georg Bauer",
	author_email = "gb@murphy.bofh.ms",
	url = "http://pyds.muensterland.org/",
	name='PyDS', 
	long_description=ldescription,
	license='MIT/X',
	platforms=['BSD','Linux','MacOS X'],
	scripts=['pyds-restore', 'pyds-start', 'pyds-stop', 'pyds-browse', 'pyds-debug'],
	packages=['PyDS'],
	data_files=[
		(dfile_dir, dfile_list),
		(tool_dir, tool_list),
		(font_dir, font_list)
	]
)
